==> schedwisrv-0.1.3.tar.gz: schedwisrv-0.1.3/py/tables/environments_s.py <==
# Schedwi
# Copyright (C) 2011 Herve Quatremain
# 
# This file is part of Schedwi.
# 
# Schedwi is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
# 
# Schedwi is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from sqlalchemy import Column, Integer, Text, String
from sqlalchemy.orm import relation, backref

from base import Base

from environment_var_s import environment_var_s

class environments_s(Base):
    __tablename__ = 'environments_s'

    id = Column(Integer, primary_key=True)
    name = Column(String(100))
    description = Column(Text)
    workload_date = Column(Integer, primary_key=True)

    environment_var = relation(environment_var_s,
                               order_by=environment_var_s.position,
                               backref="environments_s",
                               cascade="all, delete, delete-orphan")

    def __init__(self, name, description, workload_date):
        self.name = name
        self.description = description
        self.workload_date = workload_date

    def __str__(self):
        return self.name

==> schedwisrv-0.1.4.tar.gz: schedwisrv-0.1.4/py/tables/environments_s.py <==
# Schedwi
# Copyright (C) 2011, 2012 Herve Quatremain
#
# This file is part of Schedwi.
#
# Schedwi is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Schedwi is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from sqlalchemy.schema import Column
from sqlalchemy.types import Integer, Text, String
from sqlalchemy.orm import relation, backref

from base import Base, convert2unicode

from environment_var_s import environment_var_s


class environments_s(Base):
    __tablename__ = 'environments_s'

    id = Column(Integer, primary_key=True)
    name = Column(String(100))
    description = Column(Text)
    workload_date = Column(Integer, primary_key=True)

    environment_var = relation(environment_var_s,
                               order_by=environment_var_s.position,
                               backref="environments_s",
                               cascade="all, delete, delete-orphan")

    def __init__(self, name, description, workload_date):
        self.name = convert2unicode(name)
        self.description = convert2unicode(description)
        self.workload_date = workload_date

    def __str__(self):
        return self.name
